@@ -1,8 +1,6 @@
 # NOTE: best to place this at the top in case we want to import
 # it in other files
-from ._version import get_versions
-__version__ = get_versions()['version']
-del get_versions
+from ._version import version as __version__
 
 ### Major classes
 from .time_series import TimeSeries
@@ -12,6 +10,7 @@ from .candidate import Candidate
 
 ### Major functions
 from .search import ffa_search
+from .running_medians import running_median, fast_running_median
 
 from .libffa import (
     ffa1,
