@@ -16,6 +16,7 @@ import threadpoolctl
 from riptide import __version__, ffa_search, find_peaks, Candidate
 from riptide.clustering import cluster1d
 
+from riptide.pipeline.config_validation import validate_pipeline_config, validate_ranges
 from riptide.pipeline.dmiter import DMIterator
 from riptide.pipeline.worker_pool import WorkerPool
 from riptide.pipeline.peak_cluster import PeakCluster, clusters_to_dataframe
@@ -62,8 +63,10 @@ class Pipeline(object):
         Configuration dictionary loaded from YAML file
     """
     def __init__(self, config):
-        # TODO: validate config
-        self.config = config
+        # This only validates the format, not the actual parameter values.
+        # More checks are performed later when the parameters of the input
+        # time series are known
+        self.config = validate_pipeline_config(config)
         self.dmiter = None
         self.worker_pool = None
         self.peaks = []
@@ -137,6 +140,7 @@ class Pipeline(object):
         files: list
         """
         log.info("Preparing pipeline")
+        log.debug("Input files: {}".format(len(files)))
         conf = self.config
 
         # The DM iterator is in charge of:
@@ -144,23 +148,28 @@ class Pipeline(object):
         # - selecting the DM trials in the right range with the right dynamic step
         # - yielding them in chunks of size = number of parallel processes
         self.dmiter = DMIterator(
-            dm_min=conf['dmselect']['min'],
-            dm_max=conf['dmselect']['max'],
+            files,
+            conf['dmselect']['min'],
+            conf['dmselect']['max'],
             dmsinb_max=conf['dmselect']['dmsinb_max'],
+            fmt=conf['data']['format'],
             wmin=self.wmin(),
             fmin=conf['data']['fmin'],
             fmax=conf['data']['fmax'],
             nchans=conf['data']['nchans'],
         )
-        log.debug("Input files: {}".format(len(files)))
-        self.dmiter.prepare(files, fmt=self.config['data']['format'])
+
+        tsamp_max = self.dmiter.tsamp_max()
+        log.info(
+            f"Max sampling time = {tsamp_max:.6e} s, checking pipeline config parameter values")
+        validate_ranges(conf['ranges'], tsamp_max)
 
         # NOTE: call dmiter.prepare() first. Before that, dmiter.tsloader is None
         self.worker_pool = WorkerPool(
             conf['dereddening'], 
             conf['ranges'],
-            loader=self.dmiter.tsloader,
-            processes=conf['processes']
+            processes=conf['processes'],
+            fmt=conf['data']['format']
         )
         log.info("Pipeline ready")
         
@@ -171,7 +180,7 @@ class Pipeline(object):
         """
         log.info("Running search")
         peaks = []
-        for fnames in self.dmiter.iterate_fnames(chunksize=self.config['processes']):
+        for fnames in self.dmiter.iterate_filenames(chunksize=self.config['processes']):
             peaks.extend(
                 self.worker_pool.process_fname_list(fnames)
             )        
@@ -213,8 +222,8 @@ class Pipeline(object):
 
         log.info("Flagging harmonics")
         tobs = self.dmiter.tobs_median()
-        fmin = self.config['data']['fmin']
-        fmax = self.config['data']['fmax']
+        fmin = self.dmiter.fmin
+        fmax = self.dmiter.fmax
         kwargs = self.config['harmonic_flagging']
         
         clusters_decreasing_snr = sorted(self.clusters, key=lambda c: c.centre.snr, reverse=True)
@@ -282,8 +291,7 @@ class Pipeline(object):
 
     @timing
     def build_candidates(self):
-        log.info("Building candidates")
-        #remove_harmonics = self.config['remove_harmonics']         
+        log.info("Building candidates")      
         clusters_decreasing_snr = sorted(self.clusters_filtered, key=lambda c: c.centre.snr, reverse=True)
 
         if not clusters_decreasing_snr:
@@ -299,7 +307,8 @@ class Pipeline(object):
         log.debug(f"{len(clusters_decreasing_snr)} candidates to build from {len(grouped_clusters)} TimeSeries")
 
         for dm, clusters in grouped_clusters.items():
-            ts = self.dmiter.get_dm_trial(dm)
+            fname = self.dmiter.get_filename(dm)
+            ts = self.worker_pool.loader(fname)
             ts = ts.deredden(
                 width=self.config['dereddening']['rmed_width'], 
                 minpts=self.config['dereddening']['rmed_minpts'])
